Message

Struct Message 

pub struct Message {
Show 13 fields pub handle: Option<u64>, pub subject: Option<String>, pub timestamp: Option<i64>, pub sender: Option<Audience>, pub recipient: Option<Audience>, pub type_: Option<MessageType>, pub content: Option<String>, pub folder: Option<String>, pub priority: Option<bool>, pub read: Option<bool>, pub sent: Option<bool>, pub protected: Option<bool>, pub conversation_id: Option<[u8; 16]>, /* private fields */
}
Based on x-bt/message, x-bt/MAP-msg-listing v1.1, and MAP-Event-Report NewMessage objects. See MAP v1.4.2 sections 3.1.3 and 3.1.6 for details. Depending on the method used to get the message, not all fields may be populated.

Fields

handle: Option<u64>

Handle for this message. Locally unique to each Message Server Equipment (MSE). Always present.

subject: Option<String>

Summary of the message.

timestamp: Option<i64>

Unix timestamp that represents the sending time if it was included in the message, otherwise represents the reception time of the MSE.

sender: Option<Audience>

Information about the sender.

recipient: Option<Audience>

Information about the recipient.

type_: Option<MessageType>

Type of the message. Always present.

content: Option<String>

Content of the message.

folder: Option<String>

Folder where the message is located in.

priority: Option<bool>

Whether or not message is high priority. If this information is missing, it would be set as unknown, not false.

read: Option<bool>

Whether or not message was read. If this information is missing, it would be set as unknown, not false.

sent: Option<bool>

Whether or not meessage has already been sent to the recipient. If this information is missing, it would be set as unknown, not false.

protected: Option<bool>

Whether or not message is protected by a DRM scheme.

conversation_id: Option<[u8; 16]>

A 128 bit value that uniquely identifies a conversation within a single MAS instance.